.. _changelog:

Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

`Unreleased <https://github.com/the-solution-desk/OrganiserPro/compare/v0.1.0...HEAD>`_
----------------------------------------------------------------------------------------

Added
~~~~~
- Initial project setup and documentation
- Core functionality for file organization and deduplication
- Command-line interface with sort and dedupe commands
- Comprehensive test suite
- GitHub Actions CI workflow

Changed
~~~~~~~
- N/A

Fixed
~~~~~
- N/A

Removed
~~~~~~~
- N/A

`0.1.0 <https://github.com/the-solution-desk/OrganiserPro/releases/tag/v0.1.0>`_ - 2025-06-29
----------------------------------------------------------------------------------------------

Added
~~~~~
- Initial release of OrganiserPro
- Basic file sorting by type and date
- Duplicate file detection and handling
- Command-line interface with help and version options

Changed
~~~~~~~
- N/A

Fixed
~~~~~
- N/A

Removed
~~~~~~~
- N/A

.. _Semantic Versioning: http://semver.org/
.. _Keep a Changelog: https://keepachangelog.com/
